@@ -16,20 +16,23 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with the Gnome Library; see the file COPYING.LIB.  If not,
- * write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 /*
   @NOTATION@
  */
 
+
 /*
  * Handles all of the internationalization configuration options.
  * Author: Tom Tromey <tromey@creche.cygnus.com>
  */
 
 #ifndef __GNOME_I18N_H__
-#define __GNOME_I18N_H__ 1
+#define __GNOME_I18N_H__
+
+#ifndef GNOME_DISABLE_DEPRECATED
 
 #include <glib.h>
 #ifdef GNOME_EXPLICIT_TRANSLATION_DOMAIN
@@ -55,7 +58,7 @@ G_BEGIN_DECLS
  *
  * LC_MONETARY="de_DE:es"
  * LANG="de_DE:de:C:en"
- * 
+ *
  * In this case 'gnome_i18n_get_language_list ("LC_COLLATE")' returns the
  * list: ("de_DE" "de" "C" "en").
  *
@@ -80,3 +83,5 @@ void		gnome_i18n_pop_c_numeric_locale		(void);
 G_END_DECLS
 
 #endif /* __GNOME_I18N_H__ */
+
+#endif /* GNOME_DISABLE_DEPRECATED */
